@@ -21,12 +21,12 @@ Create Date: 2015-02-10 17:51:10.752504
 
 """
 
-from alembic import op
-
 # revision identifiers, used by Alembic.
 revision = '3ea02b2a773e'
 down_revision = 'start_neutron_vpnaas'
 
+from alembic import op
+
 TABLES = ['ipsecpolicies', 'ikepolicies', 'ipsec_site_connections',
           'vpnservices']
 
@@ -35,3 +35,9 @@ def upgrade():
     for table in TABLES:
         op.create_index(op.f('ix_%s_tenant_id' % table),
                         table, ['tenant_id'], unique=False)
+
+
+def downgrade():
+    for table in TABLES:
+        op.drop_index(op.f('ix_%s_tenant_id' % table),
+                      table_name=table)
