@@ -75,7 +75,8 @@ class FedoraStrongSwanProcess(strongswan_ipsec.StrongSwanProcess):
         self.ensure_config_file(
             'ipsec.secrets',
             cfg.CONF.strongswan.ipsec_secret_template,
-            self.vpnservice)
+            self.vpnservice,
+            0o600)
         self.copy_and_overwrite(cfg.CONF.strongswan.default_config_area,
                                 self._get_config_filename('strongswan.d'))
         # Fedora uses /usr/share/strongswan/templates/config/ as strongswan
