@@ -12,15 +12,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from neutron_lib.db import model_base
-from neutron_lib import exceptions as nexception
+from neutron.common import exceptions
+from neutron.db import model_base
+from neutron.db import models_v2
+from neutron.i18n import _LI
 from oslo_db import exception as db_exc
 from oslo_log import log as logging
 import sqlalchemy as sa
 from sqlalchemy.orm import exc as sql_exc
 
-from neutron_vpnaas._i18n import _
-from neutron_vpnaas.db.vpn import vpn_models
+from neutron_vpnaas.db.vpn import vpn_db
 
 LOG = logging.getLogger(__name__)
 
@@ -40,17 +41,17 @@ MAPPING_LIMITS = {TUNNEL: (0, MAX_CSR_TUNNELS),
                   IPSEC_POLICY: (1, MAX_CSR_IPSEC_POLICIES)}
 
 
-class CsrInternalError(nexception.NeutronException):
+class CsrInternalError(exceptions.NeutronException):
     message = _("Fatal - %(reason)s")
 
 
-class IdentifierMap(model_base.BASEV2):
+class IdentifierMap(model_base.BASEV2, models_v2.HasTenant):
 
     """Maps OpenStack IDs to compatible numbers for Cisco CSR."""
 
     __tablename__ = 'cisco_csr_identifier_map'
 
-    ipsec_site_conn_id = sa.Column(sa.String(36),
+    ipsec_site_conn_id = sa.Column(sa.String(64),
                                    sa.ForeignKey('ipsec_site_connections.id',
                                                  ondelete="CASCADE"),
                                    primary_key=True)
@@ -103,24 +104,24 @@ def get_next_available_ipsec_policy_id(session):
 
 
 def find_conn_with_policy(policy_field, policy_id, conn_id, session):
-    """Return ID of another connection (if any) that uses same policy ID."""
-    qry = session.query(vpn_models.IPsecSiteConnection.id)
+    """Return ID of another conneciton (if any) that uses same policy ID."""
+    qry = session.query(vpn_db.IPsecSiteConnection.id)
     match = qry.filter_request(
         policy_field == policy_id,
-        vpn_models.IPsecSiteConnection.id != conn_id).first()
+        vpn_db.IPsecSiteConnection.id != conn_id).first()
     if match:
         return match[0]
 
 
 def find_connection_using_ike_policy(ike_policy_id, conn_id, session):
     """Return ID of another connection that uses same IKE policy ID."""
-    return find_conn_with_policy(vpn_models.IPsecSiteConnection.ikepolicy_id,
+    return find_conn_with_policy(vpn_db.IPsecSiteConnection.ikepolicy_id,
                                  ike_policy_id, conn_id, session)
 
 
 def find_connection_using_ipsec_policy(ipsec_policy_id, conn_id, session):
     """Return ID of another connection that uses same IPSec policy ID."""
-    return find_conn_with_policy(vpn_models.IPsecSiteConnection.ipsecpolicy_id,
+    return find_conn_with_policy(vpn_db.IPsecSiteConnection.ipsecpolicy_id,
                                  ipsec_policy_id, conn_id, session)
 
 
@@ -166,18 +167,17 @@ def determine_csr_policy_id(policy_type, conn_policy_field, map_policy_field,
 def determine_csr_ike_policy_id(ike_policy_id, conn_id, session):
     """Use existing, or reserve a new IKE policy ID for Cisco CSR."""
     return determine_csr_policy_id(IKE_POLICY,
-                                   vpn_models.IPsecSiteConnection.ikepolicy_id,
+                                   vpn_db.IPsecSiteConnection.ikepolicy_id,
                                    IdentifierMap.csr_ike_policy_id,
                                    ike_policy_id, conn_id, session)
 
 
 def determine_csr_ipsec_policy_id(ipsec_policy_id, conn_id, session):
     """Use existing, or reserve a new IPSec policy ID for Cisco CSR."""
-    return determine_csr_policy_id(
-        IPSEC_POLICY,
-        vpn_models.IPsecSiteConnection.ipsecpolicy_id,
-        IdentifierMap.csr_ipsec_policy_id,
-        ipsec_policy_id, conn_id, session)
+    return determine_csr_policy_id(IPSEC_POLICY,
+                                   vpn_db.IPsecSiteConnection.ipsecpolicy_id,
+                                   IdentifierMap.csr_ipsec_policy_id,
+                                   ipsec_policy_id, conn_id, session)
 
 
 def get_tunnel_mapping_for(conn_id, session):
@@ -223,9 +223,9 @@ def create_tunnel_mapping(context, conn_info):
             msg = _("Attempt to create duplicate entry in Cisco CSR "
                     "mapping table for connection %s") % conn_id
             raise CsrInternalError(reason=msg)
-        LOG.info("Mapped connection %(conn_id)s to Tunnel%(tunnel_id)d "
-                 "using IKE policy ID %(ike_id)d and IPSec policy "
-                 "ID %(ipsec_id)d",
+        LOG.info(_LI("Mapped connection %(conn_id)s to Tunnel%(tunnel_id)d "
+                     "using IKE policy ID %(ike_id)d and IPSec policy "
+                     "ID %(ipsec_id)d"),
                  {'conn_id': conn_id, 'tunnel_id': csr_tunnel_id,
                   'ike_id': csr_ike_id, 'ipsec_id': csr_ipsec_id})
 
@@ -235,4 +235,4 @@ def delete_tunnel_mapping(context, conn_info):
     with context.session.begin():
         sess_qry = context.session.query(IdentifierMap)
         sess_qry.filter_by(ipsec_site_conn_id=conn_id).delete()
-    LOG.info("Removed mapping for connection %s", conn_id)
+    LOG.info(_LI("Removed mapping for connection %s"), conn_id)
