@@ -16,9 +16,7 @@ from neutron.common import rpc as n_rpc
 from oslo_log import log as logging
 import oslo_messaging
 
-from neutron.db.models import servicetype
-
-from neutron_vpnaas.db.vpn import vpn_models
+from neutron_vpnaas.db.vpn import vpn_db
 from neutron_vpnaas.services.vpn.common import topics
 from neutron_vpnaas.services.vpn import service_drivers
 from neutron_vpnaas.services.vpn.service_drivers import base_ipsec
@@ -57,19 +55,12 @@ class CiscoCsrIPsecVpnDriverCallBack(object):
         return n_rpc.PluginRpcDispatcher([self])
 
     def get_vpn_services_using(self, context, router_id):
-        query = context.session.query(vpn_models.VPNService)
-        query = query.join(
-            servicetype.ProviderResourceAssociation,
-            servicetype.ProviderResourceAssociation.resource_id ==
-            vpn_models.VPNService.id)
-        query = query.join(vpn_models.IPsecSiteConnection)
-        query = query.join(vpn_models.IKEPolicy)
-        query = query.join(vpn_models.IPsecPolicy)
-        query = query.join(vpn_models.IPsecPeerCidr)
-        query = query.filter(vpn_models.VPNService.router_id == router_id)
-        query = query.filter(
-            servicetype.ProviderResourceAssociation.provider_name ==
-            self.driver.name)
+        query = context.session.query(vpn_db.VPNService)
+        query = query.join(vpn_db.IPsecSiteConnection)
+        query = query.join(vpn_db.IKEPolicy)
+        query = query.join(vpn_db.IPsecPolicy)
+        query = query.join(vpn_db.IPsecPeerCidr)
+        query = query.filter(vpn_db.VPNService.router_id == router_id)
         return query.all()
 
     def get_vpn_services_on_host(self, context, host=None):
@@ -131,11 +122,11 @@ class CiscoCsrIPsecVPNDriver(base_ipsec.BaseIPsecVPNDriver):
     def __init__(self, service_plugin):
         super(CiscoCsrIPsecVPNDriver, self).__init__(
             service_plugin,
-            cisco_validator.CiscoCsrVpnValidator(self))
+            cisco_validator.CiscoCsrVpnValidator(service_plugin))
 
     def create_rpc_conn(self):
         self.endpoints = [CiscoCsrIPsecVpnDriverCallBack(self)]
-        self.conn = n_rpc.create_connection()
+        self.conn = n_rpc.create_connection(new=True)
         self.conn.create_consumer(
             topics.CISCO_IPSEC_DRIVER_TOPIC, self.endpoints, fanout=False)
         self.conn.consume_in_threads()
@@ -205,8 +196,6 @@ class CiscoCsrIPsecVPNDriver(base_ipsec.BaseIPsecVPNDriver):
     def make_vpnservice_dict(self, context, vpnservice, router_info):
         """Collect all service info, including Cisco info for IPSec conn."""
         vpnservice_dict = dict(vpnservice)
-        # Populate tenant_id for RPC compat
-        vpnservice_dict['tenant_id'] = vpnservice_dict['project_id']
         vpnservice_dict['ipsec_conns'] = []
         vpnservice_dict['subnet'] = dict(vpnservice.subnet)
         vpnservice_dict['router_info'] = self._get_router_info(router_info)
