@@ -13,13 +13,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from neutron_lib import rpc as n_rpc
+from neutron.common import rpc as n_rpc
+from oslo_log import log as logging
 
 from neutron_vpnaas.services.vpn.common import topics
 from neutron_vpnaas.services.vpn.service_drivers import base_ipsec
-from neutron_vpnaas.services.vpn.service_drivers import ipsec_validator
 
 
+LOG = logging.getLogger(__name__)
+
 IPSEC = 'ipsec'
 BASE_IPSEC_VERSION = '1.0'
 
@@ -28,13 +30,11 @@ class IPsecVPNDriver(base_ipsec.BaseIPsecVPNDriver):
     """VPN Service Driver class for IPsec."""
 
     def __init__(self, service_plugin):
-        super(IPsecVPNDriver, self).__init__(
-            service_plugin,
-            ipsec_validator.IpsecVpnValidator(self))
+        super(IPsecVPNDriver, self).__init__(service_plugin)
 
     def create_rpc_conn(self):
         self.endpoints = [base_ipsec.IPsecVpnDriverCallBack(self)]
-        self.conn = n_rpc.Connection()
+        self.conn = n_rpc.create_connection(new=True)
         self.conn.create_consumer(
             topics.IPSEC_DRIVER_TOPIC, self.endpoints, fanout=False)
         self.conn.consume_in_threads()
