@@ -14,11 +14,13 @@
 #    under the License.
 #
 
+import contextlib
+
 import mock
-from neutron_lib import context as n_ctx
-from neutron_lib.plugins import constants
-from neutron_lib.plugins import directory
-from oslo_utils import uuidutils
+
+from neutron import context as n_ctx
+from neutron.openstack.common import uuidutils
+from neutron.plugins.common import constants
 
 from neutron_vpnaas.services.vpn.service_drivers import vyatta_ipsec
 from neutron_vpnaas.tests import base
@@ -46,8 +48,13 @@ class TestVyattaDriver(base.BaseTestCase):
         l3_agent.host = FAKE_HOST
         plugin = mock.Mock()
         plugin.get_l3_agents_hosting_routers.return_value = [l3_agent]
-        directory.add_plugin(constants.CORE, plugin)
-        directory.add_plugin(constants.L3, plugin)
+        plugin_p = mock.patch('neutron.manager.NeutronManager.get_plugin')
+        get_plugin = plugin_p.start()
+        get_plugin.return_value = plugin
+        service_plugin_p = mock.patch(
+            'neutron.manager.NeutronManager.get_service_plugins')
+        get_service_plugin = service_plugin_p.start()
+        get_service_plugin.return_value = {constants.L3_ROUTER_NAT: plugin}
         service_plugin = mock.Mock()
         service_plugin.get_l3_agents_hosting_routers.return_value = [l3_agent]
         self._fake_vpn_router_id = _uuid()
@@ -58,10 +65,12 @@ class TestVyattaDriver(base.BaseTestCase):
 
     def _test_update(self, func, args, additional_info=None):
         ctxt = n_ctx.Context('', 'somebody')
-        with mock.patch.object(self.driver.agent_rpc.client, 'cast'
-                               ) as rpc_mock, \
-                mock.patch.object(self.driver.agent_rpc.client, 'prepare'
-                                  ) as prepare_mock:
+        with contextlib.nested(
+            mock.patch.object(self.driver.agent_rpc.client, 'cast'),
+            mock.patch.object(self.driver.agent_rpc.client, 'prepare'),
+        ) as (
+            rpc_mock, prepare_mock
+        ):
             prepare_mock.return_value = self.driver.agent_rpc.client
             func(ctxt, *args)
 
